@@ -2,10 +2,7 @@ from abc import ABC, abstractmethod
 from collections import defaultdict
 
 
-from ..exceptions import (
-    UICaptchaNotSolved,
-    ParamsException,
-)
+from ..exceptions import UICaptchaNotSolved
 
 from ..browser.browser import Browser
 from ..api.captcha_guru import CaptchaGuru
@@ -20,20 +17,21 @@ class Captcha(ABC):
         """
         :param params: Captcha settings. Possible values:
             - captcha_type: 'v2' or 'image'. Required
-            - browser: Instance of RPA.Browser.Selenium.Selenium().  Required for 'v2' and 'image' captcha in case image_source is not provided
+            - browser: Instance of RPA.Browser.Selenium.Selenium().
+                       Required for 'v2' and 'image' captcha in case image_source is not provided
             - captcha_guru_api_key: Valid api key. Required
             - image_xpath: Image with captcha. Required if browser is provided
             - input_xpath: Input token to this input field. Valid for image captcha
             - click_xpath: Click button after captcha solved
             - check_xpath: Search for locator after captcha submitted
-            - image_source: path to image file. Required for 'image' captcha if browser is not provided. 
+            - image_source: path to image file. Required for 'image' captcha if browser is not provided.
             - upper: make Solved token.upper() for image captcha. Valid for image captcha
         """
-               
+
         self.api_provider = CaptchaGuru(params["captcha_guru_api_key"])
 
         self.params = defaultdict(str, params)
-  
+
         if not self.params["image_source"]:
             self.browser = Browser(params["browser"])
 
@@ -59,8 +57,6 @@ class Captcha(ABC):
         :raises UICaptchaNotSolved: if 'check_xpath' not found. This means that captcha is not solved
         """
         try:
-            self.browser.wait_until_page_contains_element(
-                self.params["check_xpath"], timeout=5
-            )
-        except:
+            self.browser.wait_until_page_contains_element(self.params["check_xpath"], timeout=5)
+        except Exception:
             raise UICaptchaNotSolved()
